lenstronomy.LensModel.LightConeSim package — lenstronomy 1.9.1 documentation

# lenstronomy.LensModel.LightConeSim package

## Submodules

## lenstronomy.LensModel.LightConeSim.light_cone module

class `lenstronomy.LensModel.LightConeSim.light_cone.` `LightCone`(mass_map_list, grid_spacing_list, redshift_list)

  Bases: `object`

  class to perform multi-plane ray-tracing from convergence maps at different redshifts From the convergence maps the deflection angles and lensing potential are computed (from different settings) and then an interpolated grid of all those quantities generate an instance of the lenstronomy LensModel multi-plane instance. All features of the LensModel module are supported.

  Improvements that can be made for accuracy and speed: 1. adaptive mesh integral for the convergence map 2. Interpolated deflection map on different scales than the mass map.

  The design principles should allow those implementations ‘under the hook’ of this class.

  `cone_instance`(z_source, cosmo, multi_plane=True)

    Parameters: | z_source – redshift to where lensing quantities are computed cosmo – astropy.cosmology class multi_plane – boolean, if True, computes multi-plane ray-tracing
    Returns: | LensModel instance, keyword argument list of lens model

class `lenstronomy.LensModel.LightConeSim.light_cone.` `MassSlice`(mass_map, grid_spacing, redshift)

  Bases: `object`

  class to describe a single mass slice

  `interpol_instance`(z_source, cosmo)

    scales the mass map integrals (with units of mass not convergence) into a convergence map for the given cosmology and source redshift and returns the keyword arguments of the interpolated reduced deflection and lensing potential.

    Parameters: | z_source – redshift of the source cosmo – astropy.cosmology instance
    Returns: | keyword arguments of the interpolation instance with numerically computed deflection angles and lensing potential

## Module contents